@@ -1,17 +1,17 @@
 from .asserts import *
 from .context import *
 from .runner import start
+from .runner import common
 from .annotations import *
 from .classes.mocking import *
-from .runner import common_parameters
 from .classes.fluent_assert import verify
 from .classes.soft_assert import SoftAssert
 from .classes.listeners.file_logger import DefaultFileListener
 
-__all__ = ['start', 'common_parameters', 'SoftAssert', 'Spy', 'TestDouble', 'DefaultFileListener',
+__all__ = ['start', 'common', 'SoftAssert', 'Spy', 'TestDouble', 'DefaultFileListener',
            'DATA_FILE', 'CONTAINER', 'provider',
            'equals', 'is_none', 'is_not_none', 'should_raise', 'test_fail', 'test_break', 'test_skip',
            'no_exception_expected', 'contains', 'verify', 'not_contains', 'not_equals', 'is_false', 'is_true',
            'mock_builtins', 'mock', 'mock_input', 'mock_print', 'mock_open',
            'is_zero', 'is_positive', 'is_negative', 'is_empty', 'is_not_empty', 'Stub',
-           'test', 'before', 'after', 'before_group', 'after_group', 'before_suite', 'after_suite']
+           'test', 'before', 'after', 'before_group', 'after_group', 'before_suite', 'after_suite', 'common_function']
