@@ -1,3 +1,5 @@
+from typing import NoReturn
+
 from .calls import Call
 
 
@@ -6,5 +8,5 @@ class Observer:
     def __init__(self):
         pass
 
-    def notify(self, call_: Call):
+    def notify(self, call_: Call) -> NoReturn:
         raise NotImplementedError()
